import {
  Metadata, Loader, IEventParam, IDictionary, Http, Config, I18n, Datasource, Mask,
} from '@zeedhi/core';
import {
  Select, GridEditable, Form, Button, Card, DialogService, LoadingService, Number as NumberInput, ModalService, Modal,
  IComponentRender,
} from '@zeedhi/common';
import { TekGrid } from '@zeedhi/teknisa-components-common';
import { PmeMask } from '@/config';

export class Pme04000RealocacaoComensaisEspeciaisPrato {
  public appController = Loader.getInstance('AppController');
  
  public utilities = Loader.getInstance('Utilities');
  
  public gridEditableController = Loader.getInstance('GridEditableController');
  
  public crudController = Loader.getInstance('CrudController');
  
  private comensaisIsVisible = false;
  
  public selectedPrato = '';

  public modalExportacao!: Modal;
  
  public pratoOrigComponentProps = {
    component: 'ZdSelect',
    dataText: [
      {
        name: 'CDPRATO_ORIG',
        mask: (Config.masks.plateMask as PmeMask).pattern,
      },
      'NMPRATO_ORIG',
    ],
    formatterDataText: [
      {
        name: 'CDPRATO_ORIG',
        mask: (Config.masks.plateMask as PmeMask).pattern,
      },
      'NMPRATO_ORIG',
    ],
    dataValue: 'CDPRATO_ORIG',
  };
  
  public pratoDestComponentProps = {
    component: 'ZdSelect',
    dataText: [
      {
        name: 'CDPRATO_DEST',
        mask: (Config.masks.plateMask as PmeMask).pattern,
      },
      'NMPRATO_DEST',
    ],
    formatterDataText: [
      {
        name: 'CDPRATO_DEST',
        mask: (Config.masks.plateMask as PmeMask).pattern,
      },
      'NMPRATO_DEST',
    ],
    dataValue: 'CDPRATO_DEST',
  };
  
  public filterTipoCardapio({ component }: IEventParam<Select>) {
    const sufix = component.name.split('_')[1];
    let filiName = '';
    let central;
    if (sufix) {
      filiName = `CDFILIAL_${sufix}`;
      central = Metadata.getInstance<Select>(`CENTRAL_${sufix}`).value || '';
    } else {
      filiName = 'UNIDADE_AGREGADA';
      central = this.appController.getCdCentral();
    }
    const unidade = Metadata.getInstance<Select>(filiName);
    const conditions = [
      {
        name: 'CDFILIAL',
        operator: '=',
        value: unidade.value ? unidade.value : '',
      },
      {
        name: 'CDFILCENTPME',
        operator: '=',
        value: central,
      },
      {
        name: 'NRPASTATCARD',
        operator: '=',
        value: 'T',
      },
    ];
    
    component.datasource.filter = conditions;
    component.datasource.get();
  }
  
  public filterTipoCardapioExport({ component }: IEventParam<Select>) {
    const sufix = component.name.split('_')[1];
    const central = Metadata.getInstance<Select>(`CENTRAL_${sufix}`).value || '';
    const unidade = Metadata.getInstance<Select>(`CDFILIAL_${sufix}`);
    const conditions = [
      {
        name: 'CDFILIAL',
        operator: '=',
        value: unidade.value.length > 0 ? unidade.value.join('_') : 'T',
      },
      {
        name: 'CDFILCENTPME',
        operator: '=',
        value: central,
      },
      // {
      //   name: 'NRPASTATCARD',
      //   operator: '=',
      //   value: 'T',
      // },
    ];
    
    component.datasource.filter = conditions;
    component.datasource.get();
  }
  
  public changeUnidade({ component }: IEventParam<Select>) {
    const sufix = component.name.split('_')[1];
    let name = '';
    if (sufix && sufix !== 'AGREGADA') name = `TPCARD_${sufix}`;
    else name = 'TPCARD';
    const tipoCard = Metadata.getInstance<Select>(name);
    tipoCard.setValue('');
  }
  
  public filterAgregada({ component }: IEventParam<Select>) {
    const grid = Metadata.getInstance<GridEditable>('COMESPPRAT');
    component.datasource.filter = [
      {
        name: 'CDFILCENTPME',
        operator: '=',
        value: this.appController.getCdCentral(),
      },
    ];
    component.datasource.get();
    grid.datasource.updateData([]);
    grid.datasource.total = 0;
  }
  
  public filterAgregadaExport({ component }: IEventParam<Select>) {
    const sufix = component.name.split('_')[1];
    const central = Metadata.getInstance<Select>(`CENTRAL_${sufix}`);
    component.datasource.filter = [
      {
        name: 'CDFILCENTPME',
        operator: '=',
        value: central.value,
      },
    ];
    component.datasource.get();
  }
  
  public filterComensaisEspeciais() {
    const unidade = Metadata.getInstance<Select>('UNIDADE_AGREGADA');
    const grid: GridEditable = Metadata.getInstance('REALCOMESPPRAT');
    const tipoCard = Metadata.getInstance<Select>('TPCARD').selectValue;
    const form = Metadata.getInstance<Form>('formFilter');
    if (form.validate()) {
      const conditions = [
        {
          name: 'CDFILIAL',
          operator: '=',
          value: unidade.value ? unidade.value : '',
        },
        {
          name: 'CDFILCENTPME',
          operator: '=',
          value: this.appController.getCdCentral(),
        },
        {
          name: 'CDTIPOCARD',
          operator: '=',
          value: tipoCard ? tipoCard.CDTIPOCARD : '',
        },
      ];
      grid.datasource.filter = conditions;
      grid.datasource.get();
    } else {
      grid.datasource.data = [];
      grid.datasource.selectedRows = [];
    }
  }
  
  public addRow({ component }: IEventParam<Button>) {
    const grid = this.utilities.returnGrid(component) as GridEditable;
    const form = Metadata.getInstance<Form>('formFilter');
    if (form.validate() && !grid.editing) {
      this.gridEditableController.addRow({ component: grid });
      if (grid.name === 'COMESPPRAT') {
        setTimeout(() => {
          const qt = Metadata.getInstance<NumberInput>('QTCOMESPRAT_editable_');
          qt.value = null;
        }, 100);
      }
    }
  }
  
  public cancelEditingGrid({ component }: IEventParam<Button>) {
    this.gridEditableController.cancelEditing({ component });
  }
  
  public cancelEditingComensais({ component }: IEventParam<Button>) {
    this.gridEditableController.cancelEditing({ component });
    // const qtComensais = Metadata.getInstance<NumberInput>('QTCOMESPRAT');
    // qtComensais.value = null;
  }
  
  public saveComEspPrat({ component }: IEventParam<Button>) {
    const grid = Metadata.getInstance<GridEditable>('COMESPPRAT');
    const gridPrincipal = Metadata.getInstance<GridEditable>('REALCOMESPPRAT');
    const editedRows: IDictionary = grid.getEditedRows(false, true);

    if (grid.isGridValid(true)) {
      if (editedRows.length > 0) {
        if (grid) grid.datasource.loading = true;
        const unidade = Metadata.getInstance<Select>('UNIDADE_AGREGADA');
        const tpcard = Metadata.getInstance<Select>('TPCARD');
        editedRows.forEach((row: IDictionary) => {
          row.CDREALCOMESPPRATPME = gridPrincipal.datasource.currentRow.CDREALCOMESPPRATPME;
          row.CDFILCENTPME = this.appController.getCdCentral();
          row.CDFILIAL = unidade.value;
          row.CDTIPOCARD = tpcard.value;
          if (!row.CDTIPOPRAT && !row.CDPRATO && !row.CDFILAUXPRAT) {
            const l = grid.datasource.data.length;
            row.CDTIPOPRAT = grid.datasource.data[l - 1].CDTIPOPRAT;
            row.CDPRATO = grid.datasource.data[l - 1].CDPRATO;
            row.CDFILAUXPRAT = grid.datasource.data[l - 1].CDFILAUXPRAT;
            row.CDCOMESPPRATPME = grid.datasource.data[l - 1].CDCOMESPPRATPME;
            row.__is_new = false;
          }
        });
        LoadingService.show(' ');
        Http.post('/saveComEspPrat', { editedRows }).then((response: IDictionary) => {
          if (response.data.length === 0) {
            // grid.datasource.get();
            this.utilities.showAlert('alertSuccess', 'Salvo com sucesso!', 'success');
            this.gridEditableController.cancelEditing({ component });
            // this.gridEditableController.defaultState(grid);
          } else {
            const mensagem = response.data.dataset.message.message;
            if (mensagem.indexOf('Impossível adicionar. Registro já existe.') === 0) {
              this.utilities.showAlert('alertError', I18n.translate('Impossível adicionar. Registro já existe.'), 'error');
            } else if (mensagem.indexOf('Não é possível realocar comensais para o próprio prato.') === 0) {
              this.utilities.showAlert(
                'alertError', I18n.translate('Não é possível realocar comensais para o próprio prato.'), 'error',
              );
            }
          }
        }).catch((error: IDictionary) => {
          this.utilities.showAlert('alertError', error, 'error');
        }).finally(() => {
          LoadingService.hide();
          if (grid) grid.datasource.loading = false;
        });
      } else {
        this.gridEditableController.defaultState(grid);
        this.utilities.showAlert('alert', 'Nenhum registro editado.', 'yellow');
      }
    }
  }
  
  public saveRealComEspPrat({ component }: IEventParam<Button>) {
    const grid = Metadata.getInstance<GridEditable>('REALCOMESPPRAT');
    const editedRows: IDictionary = grid.getEditedRows(false, true);
    const form = Metadata.getInstance<Form>('formFilter');
    if (grid.isGridValid(true) && editedRows.length > 0 && form.validate()) {
      const unidade = Metadata.getInstance<Select>('UNIDADE_AGREGADA');
      const tpcard = Metadata.getInstance<Select>('TPCARD');
      if (unidade.value === null || unidade.value === undefined || tpcard.value === null || tpcard.value === undefined) {
        this.utilities.showAlert('alertError',
          I18n.translate('Informa a unidade e o tipo de cardápio para adicionar.'), 'error');
      } else {
        if (grid) grid.datasource.loading = true;
        editedRows.forEach((row: IDictionary) => {
          row.CDFILCENTPME = this.appController.getCdCentral();
          row.CDFILIAL = unidade.value;
          row.CDTIPOCARD = tpcard.value;
        });
        Http.post('/saveRealComEspPrat', { editedRows }).then((response: IDictionary) => {
          if (response.data.length === 0) {
            // grid.datasource.get();
            this.utilities.showAlert('alertSuccess', 'Salvo com sucesso!', 'success');
            this.gridEditableController.cancelEditing({ component });
          } else {
            const mensagem = response.data.dataset.message.message;
            if (mensagem.indexOf('Impossível adicionar. Registro já existe.') === 0) {
              this.utilities.showAlert('alertError', I18n.translate('Impossível adicionar. Registro já existe.'), 'error');
            }
          }
        }).catch((error: IDictionary) => {
          this.utilities.showAlert('alertError', error, 'error');
        }).finally(() => {
          if (grid) grid.datasource.loading = false;
        });
      }
    }
  }
  
  public clickRealComEspPrat({ component }: IEventParam<Datasource>) {
    const pratoSelecionado = !!component.currentRow.CDPRATO;
    const card = Metadata.getInstance<Card>('comensaisCard');

    if (pratoSelecionado) {
      const grid: GridEditable = Metadata.getInstance('COMESPPRAT');
      grid.selectedRows = [];
      // grid.columns[0].loading = true;
      const cdprato = Mask.getValueWithMask(component.currentRow.CDPRATO, this.utilities.maskPlate());
      this.selectedPrato = `${component.currentRow.CDTIPOPRAT} - ${component.currentRow.NMTIPOPRAT} `
        + `| ${cdprato} - ${component.currentRow.NMPRATO}`;
    
      const conditions = [
        {
          name: 'CDREALCOMESPPRATPME',
          operator: '=',
          value: component.currentRow.CDREALCOMESPPRATPME,
        },
      ];
      grid.datasource.filter = conditions;
      // grid.datasource.get().then(() => {
      this.cardComensaisVisible();
      // });
    } else {
      const cdprato = Mask.getValueWithMask(component.currentRow.CDPRATO, this.utilities.maskPlate());
      this.selectedPrato = `${component.currentRow.CDTIPOPRAT} - ${component.currentRow.NMTIPOPRAT} `
        + `| ${cdprato} - ${component.currentRow.NMPRATO}`;
      card.isVisible = false;
      this.comensaisIsVisible = false;
    }
  }
  
  private cardComensaisVisible() {
    const card = Metadata.getInstance<Card>('comensaisCard');
    try {
      if (!this.gridEditableController.newRow) {
        card.isVisible = true;
        this.comensaisIsVisible = true;
      } else {
        const btn = Metadata.getInstance<Button>('excluiPrato');
        this.cancelEditingComensais({ component: btn });
        // .then(() => {
        card.isVisible = true;
        this.comensaisIsVisible = true;
        // });
      }
    } catch (Error) {
      card.isVisible = false;
      this.comensaisIsVisible = false;
    }
  }
  
  get gridColsRealoc(): number {
    return this.comensaisIsVisible ? 5 : 12;
  }
  
  get gridColsComensais(): number {
    return this.comensaisIsVisible ? 7 : 12;
  }
  
  public closeCardComensais() {
    const card = Metadata.getInstance<Card>('comensaisCard');
    const gridComensais: GridEditable = Metadata.getInstance('COMESPPRAT');
    this.gridEditableController.cancelEditing({ component: gridComensais });
    
    card.isVisible = false;
    this.comensaisIsVisible = false;
  }
  
  public async deleteComEspPrat({ component }: IDictionary) {
    const grid: GridEditable = Metadata.getInstance('COMESPPRAT');
    const checkedRows = grid.selectedRows;
    if (checkedRows.length === 0) this.utilities.showAlert('alert', 'Nenhum registro selecionado.', 'warning');
    else {
      await DialogService.show({
        name: component.name,
        type: 'warning',
        title: 'Atenção',
        text: 'Deseja excluir os registros?',
        buttons: [
          {
            name: 'yesDelete',
            component: 'ZdButton',
            label: 'Sim',
            events: {
              click: () => {
                // const buttonDel: GridEditable = Metadata.getInstance('yesDelete');
                LoadingService.show(' ');
                this.crudController.deleteRows(checkedRows, 'comEspPrat').then(() => {
                  grid.cancelEditedRows();
                  // grid.datasource.get();
                  grid.selectedRows = [];
                  this.utilities.showAlert('alert', 'Excluído com sucesso!', 'success');
                }).catch((error: string) => {
                  this.utilities.showAlert('alert', `pme::${error}`, 'error');
                }).finally(() => {
                  LoadingService.hide();
                  DialogService.hide();
                });
              },
            },
            outline: true,
          },
          {
            name: 'noDelete',
            component: 'ZdButton',
            label: 'Não',
            events: { click: () => DialogService.hide() },
          },
          {
            name: 'progressLine',
            component: 'ZdProgress',
            label: 'Progress',
            indeterminate: true,
            cssClass: 'loading-progress-line',
          },
        ],
      });
    }
  }
  
  public deleteRealComEspPrat() {
    LoadingService.show(' ');
    const grid = Metadata.getInstance<GridEditable>('REALCOMESPPRAT');
    const checkedRows = grid.selectedRows;
    Http.post('/deleteRealComEspPrat', { requestType: 'Row', checkedRows }).then((response: IDictionary) => {
      if (response.data.length === 0) {
        grid.datasource.get();
        grid.selectedRows = [];
        this.utilities.showAlert('alertSuccess', 'Excluído com sucesso!', 'success');
        DialogService.hide();
      } else {
        const mensagem = response.data.dataset.message[0];
        if (mensagem.indexOf('ERROR_TEM_PRATO_REGISTRO') === 0) {
          this.utilities.showAlert('alertError',
            I18n.translate('Operação bloqueada! Registro possui prato relacionado.'), 'error');
          DialogService.hide();
        }
      }
    }).catch((error) => {
      grid.selectedRows = [];
      this.utilities.showAlert('alertError', error, 'error');
      DialogService.hide();
    }).finally(() => {
      this.closeCardComensais();
      LoadingService.hide();
    });
  }
  
  public setFilterPrato({ component }: IEventParam<Select>) {
    const unidade = Metadata.getInstance<Select>('UNIDADE_AGREGADA');
    const nivel: any = (Config.masks.plateMask as PmeMask).nivelMax;
    component.datasource.filter = [
      {
        name: 'CDFILIAL',
        operator: '=',
        value: unidade.value,
      },
      {
        name: 'CDNVPRATO',
        operator: '=',
        value: nivel,
      },
    ];
    component.datasource.get();
  }
  
  public confirmDeleteRealComEspPrat({ component }: IEventParam<Button>) {
    const grid = this.utilities.returnGrid(component) as GridEditable;
    const checkedRows = grid.selectedRows;
    if (checkedRows.length === 0) this.utilities.showAlert('alert', 'Nenhum registro selecionado.', 'warning');
    else {
      DialogService.show({
        name: 'excluiGrupo',
        type: 'warning',
        title: 'Atenção',
        text: 'Deseja excluir os registros?',
        buttons: [
          {
            name: 'yes',
            component: 'ZdButton',
            label: 'Sim',
            events: { click: () => this.deleteRealComEspPrat() },
            outline: true,
          },
          {
            name: 'no',
            component: 'ZdButton',
            label: 'Não',
            events: { click: () => DialogService.hide() },
          },
        ],
      });
    }
  }

  private async createModalExportacao() {
    this.modalExportacao = await ModalService.createFromJsonPost('',
      { jsonPath: 'pme/parametrizacao/modals/exportacaoRealocacao' });
  }

  public closeModalExportacao() {
    this.modalExportacao.destroy();
    this.modalExportacao = this.utilities.modalEmpty;
  }

  public openModalExportacao() {
    if (!this.modalExportacao) {
      this.createModalExportacao().then(() => {
        this.modalExportacao.show();
      });
    } else {
      this.modalExportacao.show();
    }
  }

  public fullscreen({ component }: IEventParam<Button>) {
    this.modalExportacao.fullscreen = !this.modalExportacao.fullscreen;
    component.iconName = (this.modalExportacao.fullscreen) ? 'mdi-fullscreen-exit' : 'mdi-fullscreen';
  }

  public async fieldDefaultValueImport({ component }: IEventParam<Select>) {
    if (component.name === 'CENTRAL_ORIGEM' || component.name === 'CENTRAL_DESTINO') {
      component.datasource.data = [this.appController.getCdCentral()];
      component.setValue(this.appController.getCdCentral());
    }
  }

  public clearDependentField({ component }: IDictionary) {
    if (component.value) {
      const sufix = component.name.split('_')[1];
      const filial: Select = Metadata.getInstance(`CDFILIAL_${sufix}`);
      const tpCard: Select = Metadata.getInstance(`TPCARD_${sufix}`);
      if (component.name === `CENTRAL_${sufix}`) {
        filial.setValue(null);
        tpCard.setValue(null);
      } else if (component.name === `CDFILIAL_${sufix}`) {
        tpCard.setValue(null);
      }
      this.setFilterGridExport();
    } else {
      const grid = Metadata.getInstance<GridEditable>('exportacaoRealocacao');
      grid.datasource.data = [];
    }
  }

  private setFilterGridExport() {
    const unidade = Metadata.getInstance<Select>('CDFILIAL_ORIGEM');
    const central = Metadata.getInstance<Select>('CENTRAL_ORIGEM');
    const tipoCard = Metadata.getInstance<Select>('TPCARD_ORIGEM').selectValue;
    const formOrig = Metadata.getInstance<Form>('formOrigemExportacaoRealocacao');
    const grid: TekGrid = Metadata.getInstance('exportacaoGrid');
    const unidadeDest = Metadata.getInstance<Select>('CDFILIAL_DESTINO');
    const centralDest = Metadata.getInstance<Select>('CENTRAL_DESTINO');
    const tipoCardDest = Metadata.getInstance<Select>('TPCARD_DESTINO');
    const formDest = Metadata.getInstance<Form>('formDestinoExportacaoRealocacao');
    if (central.value && unidade.value && tipoCard && formOrig.validate() && formDest.validate()
      && centralDest.value) {
      const conditions = [
        {
          name: 'CDFILIAL',
          operator: '=',
          value: unidade.value ? unidade.value : '',
        },
        {
          name: 'CDFILCENTPME',
          operator: '=',
          value: central.value ? central.value : '',
        },
        {
          name: 'CDTIPOCARD',
          operator: '=',
          value: tipoCard ? tipoCard.CDTIPOCARD : '',
        },
        {
          name: 'CDFILIAL_DEST',
          operator: '=',
          value: unidadeDest.value.length > 0 ? unidadeDest.value.join('_') : 'T',
        },
        {
          name: 'CDFILCENTPME_DEST',
          operator: '=',
          value: centralDest.value ? centralDest.value : '',
        },
        {
          name: 'CDTIPOCARD_DEST',
          operator: '=',
          value: tipoCardDest.value.length > 0 ? tipoCardDest.value.join('_') : 'T',
        },
      ];
      grid.datasource.filter = conditions;
      grid.datasource.limit = 50;
      grid.datasource.loadAll = false;
      grid.datasource.get();
      // grid.reload();
    } else {
      grid.datasource.filter = [];
      grid.datasource.data = [];
      grid.datasource.updateData([]);
      grid.updateGroupedData(true);
      grid.datasource.selectedRows = [];
    }
  }
  
  public reloadExport({ component }: IEventParam<Button>) {
    const tekgrid = component.parent as TekGrid;
    this.gridEditableController.isInlineEditing = false;
    tekgrid.cancelEditedRows().then(() => {
      const toolbarSlot = tekgrid.toolbarSlot;
      toolbarSlot.forEach((e: IComponentRender) => {
        if (e.name === 'cancelButton') e.disabled = true;
        if (e.name === 'saveButton') e.disabled = true;
      });
    });
  }
  
  public async saveExportRealoc({ component }: IEventParam<Button>) {
    const grid = component.parent as TekGrid;
    // const rows = grid.getEditedRows();
    if (grid.isGridValid(true)) {
      this.gridEditableController.newRow = false;
      grid.editing = false;
      const toolbarSlot = grid.toolbarSlot;
      toolbarSlot.forEach((e: IComponentRender) => {
        if (e.name === 'cancelButton') e.disabled = !e.disabled;
        if (e.name === 'saveButton') e.disabled = !e.disabled;
      });
      this.gridEditableController.isInlineEditing = grid.editing;
      const data = [...grid.datasource.data];
      await grid.datasource.updateData([]);
      await grid.datasource.updateData(data);
      grid.datasource.currentRow = {}; // para retirar a linha selecionada
    } else this.utilities.showAlert('alert', 'Verificar campos obrigatórios!', 'error');
  }

  public confirmExportRealoc() {
    // const grid = component.parent as TekGrid;
    const form = Metadata.getInstance<Form>('formOrigemExportacaoRealocacao');
    const formDest = Metadata.getInstance<Form>('formDestinoExportacaoRealocacao');
    const grid: GridEditable = Metadata.getInstance('exportacaoGrid');
    if (form.validate() && formDest.validate() && grid.datasource.data.length > 0) {
      let message = '';
      if (grid.editing) {
        message = 'Existem registros editados que ainda não foram salvos'
          + ', deseja salvá-los e executar a exportação?';
      } else message = 'Deseja executar a exportação?';
      DialogService.show({
        name: 'executeExport',
        type: 'warning',
        title: 'Atenção',
        text: message,
        buttons: [
          {
            name: 'yes',
            component: 'ZdButton',
            label: 'Sim',
            events: { click: () => this.exportRealoc() },
            outline: true,
          },
          {
            name: 'no',
            component: 'ZdButton',
            label: 'Não',
            events: { click: () => DialogService.hide() },
          },
        ],
      });
    }
  }
  
  private exportRealoc() {
    DialogService.hide();
    LoadingService.show(' ');
    const grid = Metadata.getInstance<TekGrid>('exportacaoGrid');
    const data = [...grid.datasource.data];
    // const dataToSend = [...data, ...grid.getEditedRows()];
    const dataToSend = data.filter((el: IDictionary) => {
      const edited = grid.getEditedRows().find((el1: any) => el1.KEY === el.KEY);
      if (edited) {
        el.QTCOMESPRAT = edited.QTCOMESPRAT;
      }
      return (el.QTCOMESPRAT > 0);
    });
    const gridRealoc = Metadata.getInstance<GridEditable>('REALCOMESPPRAT');
    const gridComens = Metadata.getInstance<GridEditable>('COMESPPRAT');
    Http.post('/exportRealoc', { row: dataToSend }).then((response: IDictionary) => {
      if (response.data.length === 0) {
        this.utilities.showAlert('alertSuccess', 'Exportação realizada com sucesso!', 'success');
        this.closeModalExportacao();
        this.gridEditableController.cancelEditing({ component: gridRealoc });
        this.gridEditableController.cancelEditing({ component: gridComens });
      } else {
        const mensagem = response.data.dataset.message.message;
        this.utilities.showAlert('alertError', I18n.translate(mensagem), 'error');
      }
    }).catch((error: IDictionary) => {
      this.utilities.showAlert('alertError', error, 'error');
    }).finally(() => {
      LoadingService.hide();
    });
  }
  
  public get calcModalHeight() {
    return `${window.screen.height - 100}px`;
  }
}
